hook_rgl: Hook functions to use with knitr
Description
These functions allow rgl graphics to be embedded in knitr
documents, either as bitmaps (hook_rgl with format "png"),
fixed vector graphics (hook_rgl with format "eps" or
"postscript"), or interactive WebGL graphics (hook_webgl).Usage
hook_rgl(before, options, envir)
hook_webgl(before, options, envir)
Arguments
before, options, envir
Standard knitr hook function arguments. Value
- A string to be embedded into the output, or
NULL if called
when no output is available.
See Also
rgl.Sweave embeds fixed images in Sweave documents.