powered by
Objects with material properties may have an arbitrary string set as a tag. This function retrieves the id values associated with a given tag, or the tags set on given ids.
tagged3d(tags = NULL, ids = NULL, full = FALSE, subscene = 0)
A vector of tags to use for selection.
A vector of ids to report the tags on.
logical; whether to return a dataframe containing id, type, tag, or a vector of ids or tags.
id
type
tag
Where to look: by default, the whole scene is searched. NA restricts the search to the current subscene, or a subscene id can be given.
NA
A dataframe is constructed with columns
item id
item type
item tag
If ids is specified, the return value will be in the same order as ids).
Exactly one of tags and ids must be specified.
tags
ids
# NOT RUN { open3d() ids <- plot3d(rnorm(10), rnorm(10), rnorm(10), tag = "plot") unclass(ids) tagged3d("plot") tagged3d(ids = ids, full = TRUE) # }
Run the code above in your browser using DataLab